%% Encoder Interface Example
% 14.03.2019 Nicolas

close all
clear all
clear classes


savefilename = 'save.mat';


%% Measurement encoder interface
Enc = encif('serialPort', 'COM3', 'ticksPerRevolution', 2400);


%% Plot
% Initialize plot
subplot(2,1,1);
    h1 = plot(Enc.time_s, Enc.angle_deg);
    ylabel('angle [deg]');
    xlabel('time [s]');
subplot(2,1,2);
    h2 = plot(Enc.time_s, Enc.speed_rpm);
    ylabel('speed [rpm]');
    xlabel('time [s]');

% Plot update functions    
updfcn1 = @() set(h1, 'XData', Enc.time_s, 'YData', Enc.angle_deg);
updfcn2 = @() set(h2, 'XData', Enc.time_s, 'YData', Enc.speed_rpm);

% Timer for automatic plot update
TimerObj = timer('TimerFcn', @(x,y) [updfcn1(), updfcn2()], 'StartDelay', 0, ...
    'ExecutionMode', 'fixedRate', 'Period', 1/20);


%% Start measurement (and automatic plot update)
start(TimerObj);
start(Enc);


%% Measure
pause(30);


%% Stop measurement (and automatic plot update)
stop(Enc);
stop(TimerObj);


%% Save Results
% Prepare for saving
S.time_s    = Enc.time_s;
S.angle_deg = Enc.angle_deg;
S.speed_rpm = Enc.speed_rpm;

save(savefilename, 'S');
